paml_rst-class: Class "paml_rst"
This class stores information of rst file from PAML output
Description
Class "paml_rst"
This class stores information of rst file from PAML output
Slots
fields- availabel attributes
treetext- tree text
phylo- phylo object
seq_type- one of "NT" and "AA"
tip_seq- sequences of tips
marginal_ancseq- Marginal reconstruction of ancestral sequences
joint_ancseq- Joint reconstruction of ancestral sequences
marginal_subs- sequence substitutions based on marginal_ancseq
joint_subs- sequence substitutions based on joint_ancseq
marginal_AA_subs- Amino acid sequence substitutions based on marginal_ancseq
joint_AA_subs- Amino acid sequence substitutions based on joint_ancseq
rstfile- rst file
extraInfo- extra information
See Also
codeml codeml_mlc